Struct spa_rs::headers::LastModified
source · [−]pub struct LastModified(_);Expand description
Last-Modified header, defined in
RFC7232
The Last-Modified header field in a response provides a timestamp
indicating the date and time at which the origin server believes the
selected representation was last modified, as determined at the
conclusion of handling the request.
ABNF
Expires = HTTP-dateExample values
Sat, 29 Oct 1994 19:43:31 GMT
Example
use headers::LastModified;
use std::time::{Duration, SystemTime};
let modified = LastModified::from(
SystemTime::now() - Duration::from_secs(60 * 60 * 24)
);Trait Implementations
sourceimpl Clone for LastModified
impl Clone for LastModified
sourcefn clone(&self) -> LastModified
fn clone(&self) -> LastModified
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for LastModified
impl Debug for LastModified
sourceimpl From<SystemTime> for LastModified
impl From<SystemTime> for LastModified
sourcefn from(time: SystemTime) -> LastModified
fn from(time: SystemTime) -> LastModified
Converts to this type from the input type.
sourceimpl Hash for LastModified
impl Hash for LastModified
sourceimpl Header for LastModified
impl Header for LastModified
sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.
sourcefn decode<'i, I>(values: &mut I) -> Result<LastModified, Error> where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<LastModified, Error> where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of HeaderValues.
sourceimpl Ord for LastModified
impl Ord for LastModified
sourceimpl PartialEq<LastModified> for LastModified
impl PartialEq<LastModified> for LastModified
sourcefn eq(&self, other: &LastModified) -> bool
fn eq(&self, other: &LastModified) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &LastModified) -> bool
fn ne(&self, other: &LastModified) -> bool
This method tests for !=.
sourceimpl PartialOrd<LastModified> for LastModified
impl PartialOrd<LastModified> for LastModified
sourcefn partial_cmp(&self, other: &LastModified) -> Option<Ordering>
fn partial_cmp(&self, other: &LastModified) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for LastModified
impl Eq for LastModified
impl StructuralEq for LastModified
impl StructuralPartialEq for LastModified