Struct spa_rs::http::Extensions
source · [−]pub struct Extensions { /* private fields */ }Expand description
A type map of protocol extensions.
Extensions can be used by Request and Response to store
extra data derived from the underlying protocol.
Implementations
sourceimpl Extensions
impl Extensions
sourcepub fn new() -> Extensions
pub fn new() -> Extensions
Create an empty Extensions.
sourcepub fn insert<T>(&mut self, val: T) -> Option<T> where
T: 'static + Send + Sync,
pub fn insert<T>(&mut self, val: T) -> Option<T> where
T: 'static + Send + Sync,
Insert a type into this Extensions.
If a extension of this type already existed, it will be returned.
Example
let mut ext = Extensions::new();
assert!(ext.insert(5i32).is_none());
assert!(ext.insert(4u8).is_none());
assert_eq!(ext.insert(9i32), Some(5i32));sourcepub fn get<T>(&self) -> Option<&T> where
T: 'static + Send + Sync,
pub fn get<T>(&self) -> Option<&T> where
T: 'static + Send + Sync,
Get a reference to a type previously inserted on this Extensions.
Example
let mut ext = Extensions::new();
assert!(ext.get::<i32>().is_none());
ext.insert(5i32);
assert_eq!(ext.get::<i32>(), Some(&5i32));sourcepub fn get_mut<T>(&mut self) -> Option<&mut T> where
T: 'static + Send + Sync,
pub fn get_mut<T>(&mut self) -> Option<&mut T> where
T: 'static + Send + Sync,
Get a mutable reference to a type previously inserted on this Extensions.
Example
let mut ext = Extensions::new();
ext.insert(String::from("Hello"));
ext.get_mut::<String>().unwrap().push_str(" World");
assert_eq!(ext.get::<String>().unwrap(), "Hello World");sourcepub fn remove<T>(&mut self) -> Option<T> where
T: 'static + Send + Sync,
pub fn remove<T>(&mut self) -> Option<T> where
T: 'static + Send + Sync,
Remove a type from this Extensions.
If a extension of this type existed, it will be returned.
Example
let mut ext = Extensions::new();
ext.insert(5i32);
assert_eq!(ext.remove::<i32>(), Some(5i32));
assert!(ext.get::<i32>().is_none());sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clear the Extensions of all inserted extensions.
Example
let mut ext = Extensions::new();
ext.insert(5i32);
ext.clear();
assert!(ext.get::<i32>().is_none());sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Check whether the extension set is empty or not.
Example
let mut ext = Extensions::new();
assert!(ext.is_empty());
ext.insert(5i32);
assert!(!ext.is_empty());sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Get the numer of extensions available.
Example
let mut ext = Extensions::new();
assert_eq!(ext.len(), 0);
ext.insert(5i32);
assert_eq!(ext.len(), 1);sourcepub fn extend(&mut self, other: Extensions)
pub fn extend(&mut self, other: Extensions)
Extends self with another Extensions.
If an instance of a specific type exists in both, the one in self is overwritten with the
one from other.
Example
let mut ext_a = Extensions::new();
ext_a.insert(8u8);
ext_a.insert(16u16);
let mut ext_b = Extensions::new();
ext_b.insert(4u8);
ext_b.insert("hello");
ext_a.extend(ext_b);
assert_eq!(ext_a.len(), 3);
assert_eq!(ext_a.get::<u8>(), Some(&4u8));
assert_eq!(ext_a.get::<u16>(), Some(&16u16));
assert_eq!(ext_a.get::<&'static str>().copied(), Some("hello"));Trait Implementations
sourceimpl Debug for Extensions
impl Debug for Extensions
sourceimpl Default for Extensions
impl Default for Extensions
sourcefn default() -> Extensions
fn default() -> Extensions
Returns the “default value” for a type. Read more
impl IntoResponse for Extensions
impl IntoResponse for Extensions
fn into_response(self) -> Response<UnsyncBoxBody<Bytes, Error>>
fn into_response(self) -> Response<UnsyncBoxBody<Bytes, Error>>
Create a response.
impl IntoResponseParts for Extensions
impl IntoResponseParts for Extensions
type Error = Infallible
type Error = Infallible
The type returned in the event of an error. Read more
fn into_response_parts(
self,
res: ResponseParts
) -> Result<ResponseParts, <Extensions as IntoResponseParts>::Error>
fn into_response_parts(
self,
res: ResponseParts
) -> Result<ResponseParts, <Extensions as IntoResponseParts>::Error>
Set parts of the response