Struct spa_rs::routing::MethodFilter
source · [−]pub struct MethodFilter { /* private fields */ }Expand description
A filter that matches one or more HTTP methods.
Implementations
sourceimpl MethodFilter
impl MethodFilter
sourcepub const DELETE: MethodFilter = Self{bits: 2,}
pub const DELETE: MethodFilter = Self{bits: 2,}
Match DELETE requests.
sourcepub const GET: MethodFilter = Self{bits: 4,}
pub const GET: MethodFilter = Self{bits: 4,}
Match GET requests.
sourcepub const HEAD: MethodFilter = Self{bits: 8,}
pub const HEAD: MethodFilter = Self{bits: 8,}
Match HEAD requests.
sourcepub const OPTIONS: MethodFilter = Self{bits: 16,}
pub const OPTIONS: MethodFilter = Self{bits: 16,}
Match OPTIONS requests.
sourcepub const PATCH: MethodFilter = Self{bits: 32,}
pub const PATCH: MethodFilter = Self{bits: 32,}
Match PATCH requests.
sourcepub const POST: MethodFilter = Self{bits: 64,}
pub const POST: MethodFilter = Self{bits: 64,}
Match POST requests.
sourcepub const PUT: MethodFilter = Self{bits: 128,}
pub const PUT: MethodFilter = Self{bits: 128,}
Match PUT requests.
sourcepub const TRACE: MethodFilter = Self{bits: 256,}
pub const TRACE: MethodFilter = Self{bits: 256,}
Match TRACE requests.
sourcepub const fn empty() -> MethodFilter
pub const fn empty() -> MethodFilter
Returns an empty set of flags.
sourcepub const fn all() -> MethodFilter
pub const fn all() -> MethodFilter
Returns the set containing all flags.
sourcepub const fn from_bits(bits: u16) -> Option<MethodFilter>
pub const fn from_bits(bits: u16) -> Option<MethodFilter>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u16) -> MethodFilter
pub const fn from_bits_truncate(bits: u16) -> MethodFilter
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u16) -> MethodFilter
pub const unsafe fn from_bits_unchecked(bits: u16) -> MethodFilter
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: MethodFilter) -> bool
pub const fn intersects(&self, other: MethodFilter) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: MethodFilter) -> bool
pub const fn contains(&self, other: MethodFilter) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: MethodFilter)
pub fn insert(&mut self, other: MethodFilter)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: MethodFilter)
pub fn remove(&mut self, other: MethodFilter)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: MethodFilter)
pub fn toggle(&mut self, other: MethodFilter)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: MethodFilter, value: bool)
pub fn set(&mut self, other: MethodFilter, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: MethodFilter) -> MethodFilter
pub const fn intersection(self, other: MethodFilter) -> MethodFilter
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: MethodFilter) -> MethodFilter
pub const fn union(self, other: MethodFilter) -> MethodFilter
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: MethodFilter) -> MethodFilter
pub const fn difference(self, other: MethodFilter) -> MethodFilter
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: MethodFilter) -> MethodFilter
pub const fn symmetric_difference(self, other: MethodFilter) -> MethodFilter
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> MethodFilter
pub const fn complement(self) -> MethodFilter
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.