pub struct Json<T>(pub T);Expand description
JSON Extractor / Response.
When used as an extractor, it can deserialize request bodies into some type that
implements [serde::Deserialize]. The request will be rejected (and a JsonRejection will
be returned) if:
- The request doesn’t have a
Content-Type: application/json(or similar) header. - The body doesn’t contain syntactically valid JSON.
- The body contains syntactically valid JSON but it couldn’t be deserialized into the target type.
- Buffering the request body fails.
See JsonRejection for more details.
Extractor example
use axum::{
extract,
routing::post,
Router,
};
use serde::Deserialize;
#[derive(Deserialize)]
struct CreateUser {
email: String,
password: String,
}
async fn create_user(extract::Json(payload): extract::Json<CreateUser>) {
// payload is a `CreateUser`
}
let app = Router::new().route("/users", post(create_user));When used as a response, it can serialize any type that implements [serde::Serialize] to
JSON, and will automatically set Content-Type: application/json header.
Response example
use axum::{
extract::Path,
routing::get,
Router,
Json,
};
use serde::Serialize;
use uuid::Uuid;
#[derive(Serialize)]
struct User {
id: Uuid,
username: String,
}
async fn get_user(Path(user_id) : Path<Uuid>) -> Json<User> {
let user = find_user(user_id).await;
Json(user)
}
async fn find_user(user_id: Uuid) -> User {
// ...
}
let app = Router::new().route("/users/:id", get(get_user));Tuple Fields
0: TTrait Implementations
sourceimpl<T, B> FromRequest<B> for Json<T> where
T: DeserializeOwned,
B: Body + Send,
<B as Body>::Data: Send,
<B as Body>::Error: Into<Box<dyn Error + Sync + Send + 'static, Global>>,
impl<T, B> FromRequest<B> for Json<T> where
T: DeserializeOwned,
B: Body + Send,
<B as Body>::Data: Send,
<B as Body>::Error: Into<Box<dyn Error + Sync + Send + 'static, Global>>,
type Rejection = JsonRejection
type Rejection = JsonRejection
If the extractor fails it’ll use this “rejection” type. A rejection is a kind of error that can be converted into a response. Read more
sourcefn from_request<'life0, 'async_trait>(
req: &'life0 mut RequestParts<B>
) -> Pin<Box<dyn Future<Output = Result<Json<T>, <Json<T> as FromRequest<B>>::Rejection>> + Send + 'async_trait, Global>> where
'life0: 'async_trait,
Json<T>: 'async_trait,
fn from_request<'life0, 'async_trait>(
req: &'life0 mut RequestParts<B>
) -> Pin<Box<dyn Future<Output = Result<Json<T>, <Json<T> as FromRequest<B>>::Rejection>> + Send + 'async_trait, Global>> where
'life0: 'async_trait,
Json<T>: 'async_trait,
Perform the extraction.
sourceimpl<T> IntoResponse for Json<T> where
T: Serialize,
impl<T> IntoResponse for Json<T> where
T: Serialize,
sourcefn into_response(self) -> Response<UnsyncBoxBody<Bytes, Error>>
fn into_response(self) -> Response<UnsyncBoxBody<Bytes, Error>>
Create a response.
impl<T> Copy for Json<T> where
T: Copy,